<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 09/14/2008 *
 * ===================                          Last change: 09/14/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : purge-tsks.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : Automatical purging of outdated mail links       *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auto-Loeschung von veralteten Mail-Links         *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Abort if autopurge is not active or disabled by admin
if ((!isExtensionActive('autopurge')) || (!isAutoPurgingActive()) || (getConfig('ap_tasks_notify') == 'N')) {
	// Abort here
	return FALSE;
} // END - if

// Check version (must be >= 0.1.9)
if ((isExtensionInstalledAndNewer('task', '0.1.9')) && (getConfig('autopurge_tasks') == 'Y')) {
	// Select all tasks that needs purging
	$result = sqlQuery("SELECT
	`id`,
	`assigned_admin`,
	`userid`,
	`status`,
	`task_type`,
	`subject`,
	`task_created`
FROM
	`{?_MYSQL_PREFIX?}_task_system`
WHERE
	`status`='DELETED' AND
	(UNIX_TIMESTAMP() - `task_created`) >= {?ap_tasks_time?}", __FILE__, __LINE__);

	// Send out a notification?
	if (!ifSqlHasZeroNums($result)) {
		// Init output and load all rows
		$output = ''; $ids = array();
		while ($row = sqlFetchArray($result)) {
			// "Translate" creation timestamp
			$row['task_created'] = generateDateTime($row['task_created'], '1');

			// Load row template
			$output .= loadEmailTemplate('admin_purge_task_row', $row);

			// Remember id number for deletion
			array_push($ids, $row['id']);
		} // END - while

		// Init content array
		$content = array(
			'count' => sqlNumRows($result),
			'rows'  => $output
		);

		// Delete all tasks
		sqlQuery('DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_task_system` WHERE `id` IN (' . implode(', ', $ids) . ')', __FILE__, __LINE__);

		// Send out email to admin
		sendAdminNotification('{--ADMIN_AUTOPURGE_TASKS_SUBJECT--}', 'admin_purge_task', $content);
	} // END - if

	// Free result
	sqlFreeResult($result);
} // END - if

//
?>
